@@ -1,11 +1,9 @@
-pub fn to_postgresql_type(json_type: &str)-> String {
-
+pub fn to_postgresql_type(json_type: &str) -> String {
     match json_type {
         "text" => "TEXT".to_string(),
         "date" => "TIMESTAMP".to_string(),
         "number" => "NUMERIC".to_string(),
         "boolean" => "BOOLEAN".to_string(),
-        _ => "TEXT".to_string()
+        _ => "TEXT".to_string(),
     }
-
 }
